<!DOCTYPE html>
<html lang="en">
    <head>
        {% if title %}
            <title>{{title}}</title>
        {% endif %}
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3" crossorigin="anonymous">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css">
    </head>
    <nav class="nav">
        <a class="nav-link" href="/experiments">Experiments</a>
        <a class="nav-link" href="/experiments/compare">Diff</a>
    </nav>
    <body>
        {% block content %}{% endblock %}
    </body>
</html>
